@@ -15,8 +15,9 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
+use Regexp::Common;
 
-our $VERSION = version->new('0.0.4');
+our $VERSION = version->new('0.0.5');
 
 my $opt = Getopt::Alt->new(
     {
@@ -38,9 +39,9 @@ my $opt = Getopt::Alt->new(
 
 sub _num_sort {
     my $A = $a;
-    $A =~ s/(\d+)/sprintf "%09i", $1/egxms;
+    $A =~ s/($RE{num}{real})/sprintf "%013f", $1/egxms;
     my $B = $b;
-    $B =~ s/(\d+)/sprintf "%09i", $1/egxms;
+    $B =~ s/($RE{num}{real})/sprintf "%013f", $1/egxms;
     $A cmp $B;
 }
 
@@ -95,10 +96,13 @@ Group::Git::Cmd::SinceRelease - Gets the number of commits each repository is ah
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.4
+This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.5
 
 =head1 SYNOPSIS
 
+   group-git since-release [(-m|--min-commits) n] [-n|--name]
+   group-git since-release --no-release
+   group-git since-release (-r|--released)
    group-git since-release [options]
 
    Options:
@@ -117,6 +121,12 @@ This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.4
 
 =head1 DESCRIPTION
 
+The C<since-release> command reports the statuses of repositories relative to
+their last release. Usually reporting the number of releases since the last
+release but with the C<--released> option shows only with no new commits since
+the last release. Also with the C<--no-release> option only repositories with
+no tagged releases are reported.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 C<since_release ($name)>
